#
#
#
#
#
#
#
#
#
#
# Read me first:
#
# Before you start you should make sure that the working directory is set to the
# directory of this file.
#
#
#
#
#
#
#
#
#
#

library(psyosphere)

# 00 Check directories ---------------------------------------------------------

if (!file.exists("leadership1.R")) {stop("Set the working dir correctly")}

dir.create("leadership1", showWarnings = FALSE)

dir.create("leadership1/rdata", showWarnings = FALSE)
dir.create("leadership1/plots", showWarnings = FALSE)
dir.create("leadership1/gps_files", showWarnings = FALSE)

# 01 store GPX files in data frame ---------------------------------------------

# Download and unzip files
url <- "https://analyse-gps.com/downloads/leadership1.zip"
download.file(url = url, destfile = "leadership1/gps_files.zip")
unzip("leadership1/gps_files.zip", exdir = "leadership1/gps_files")
remove(url)

# Save GPS files with participant movement as dataframe
tracks <- psyosphere::dir_get_gpx("leadership1/gps_files")

save.image("leadership1/rdata/01.RData")

# 02 add information from id file to data frame --------------------------------

# The CSV stores some data about each participants that will be added to the
# data frame.

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/01.RData")

tracks <- psyosphere::dir_add_csv(tracks, "leadership1/gps_files/ids.csv")

# Remove partcipants that are excluded
tracks <- tracks[ tracks[,c("include")] == 1 ,]

# Get first descriptives
begin_des <- des_summary(tracks)

save.image("leadership1/rdata/02.RData")

# 03 clean-up data -------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/02.RData")

# Remove time duplicates
tracks <- psyosphere::average_duplicates(tracks)

# Mark time interval gaps between coordinates
tracks <- psyosphere::t_time_difference(tracks)
tracks <- psyosphere::mark_time_gaps(tracks)

save.image("leadership1/rdata/03.RData")

# 04 add speed -----------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/03.RData")

# Add speed
tracks <- psyosphere::t_speed(tracks)

# Mark impossible speed as gaps
tracks <- psyosphere::mark_speed_gaps(tracks,40)

save.image("leadership1/rdata/04.RData")

# 05 save all plots but do not display them ------------------------------------

# The plots are generated to give you an idea how the data look like. You can
# check the plots in the plots folder in this directory.

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/04.RData")

psyosphere::plot_tracks(
  tracks, single = FALSE, save_dir = "leadership1/plots", cgaps = c("time_gap", "speed_gap")
)

save.image("leadership1/rdata/05.RData")

# 06 add bearing ---------------------------------------------------------------

# This function will add the bearing between each point of a track.

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/05.RData")

tracks <- psyosphere::t_bearing(tracks)

save.image("leadership1/rdata/06.RData")

# 07 add distance --------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/06.RData")

tracks <- psyosphere::t_distance(tracks)

save.image("leadership1/rdata/07.RData")

# 08 add average distance to team mates ----------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/07.RData")

tracks <- psyosphere::distance_peers(tracks, cpeer = "team")

save.image("leadership1/rdata/08.RData")

# 09 add average distance to not leader team mates -----------------------------

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/08.RData")

follower_tracks <- tracks[ tracks[,c("leader")] != 1  ,]
follower_tracks <- psyosphere::distance_peers(
  follower_tracks, cpeer = "team", cname = "non_leader_mean_dis"
)

leader_tracks <- tracks[ tracks[,c("leader")] == 1  ,]
leader_tracks[c("non_leader_mean_dis")] <- leader_tracks[c("average_dis")]

tracks <- rbind(follower_tracks, leader_tracks)
tracks <- tracks[order(tracks$id, tracks$p_id),]

remove(follower_tracks, leader_tracks)

save.image("leadership1/rdata/09.RData")

# 10 create summary data frame -------------------------------------------------
rm(list = ls(all.names = TRUE))
load("leadership1/rdata/09.RData")

cgaps <- c("time_gap","speed_gap")

summary <- des_summary(tracks, cgaps = cgaps)
summary <- des_first(tracks, "leader", cname = "leader", des_df = summary)

summary <- des_sd(
  tracks, ctarget = "speed", cweight = "time_difference", cgaps = cgaps,
  cname = "sd_kmh", des_df = summary
)

summary <- des_mean(
  tracks, ctarget = "average_dis", cweight = "time_difference",
  cgaps = cgaps, cname = "mean_team_distance", des_df = summary
)

summary <- des_mean(
  tracks, ctarget = "non_leader_mean_dis", cweight = "time_difference",
  cgaps = cgaps, cname = "mean_non_leader_dis", des_df = summary
)

save.image("leadership1/rdata/10.RData")

# 11 export to excel -----------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership1/rdata/10.RData")

library(xlsx)
xlsx::write.xlsx(summary, "leadership1/leadership1.xlsx")
