#
#
#
#
#
#
#
#
#
#
# Read me first:
#
# Before you start you should make sure that the working directory is set to the
# directory of this file.
#
#
#
#
#
#
#
#
#
#

library(psyosphere)

# 01 Check directories ---------------------------------------------------------

if (!file.exists("leadership3.R")) {stop("Set the working dir correctly")}

dir.create("leadership3", showWarnings = FALSE)

dir.create("leadership3/rdata", showWarnings = FALSE)
dir.create("leadership3/plots", showWarnings = FALSE)
dir.create("leadership3/plots/all", showWarnings = FALSE)
dir.create("leadership3/gps_files", showWarnings = FALSE)

# 02 Download and unzip files --------------------------------------------------

url <- "https://analyse-gps.com/downloads/leadership3.zip"
download.file(url = url, destfile = "leadership3/gps_files.zip")
unzip("leadership3/gps_files.zip", exdir = "leadership3/gps_files")
remove(url)

# 03 Store GPX files in data frame ---------------------------------------------

rm(list = ls(all.names = TRUE))

tracks <- psyosphere::dir_get_gpx("leadership3/gps_files")

save.image("leadership3/rdata/03.RData")

# 04 Save all plots ------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/03.RData")

# The plots are generated to give you an idea how the data look like. You can
# check the plots in the plots folder in this directory.

psyosphere::plot_tracks(
  tracks, single = FALSE, save_dir = "leadership3/plots/all"
)

# For each participant there are two tracks. After creating the plots it was
# possible to decide which tracks are included and which not. Tracks with more
# coordinates and less gaps were preferred. In the "ids.csv" in the gps_files
# directory is noted which files were included and which were excluded.

save.image("leadership3/rdata/04.RData")

# 05 add id file info to data frame --------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/04.RData")

# The CSV stores some data about each participants that will be added to the
# data frame.

tracks <- psyosphere::dir_add_csv(tracks, "leadership3/gps_files/ids.csv")

save.image("leadership3/rdata/05.RData")

# 06 Clean-up data -------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/05.RData")

# Remove partcipants that are excluded
tracks <- tracks[ tracks[,c("include")] == 1 ,]

# Get first descriptives
begin_des <- des_summary(tracks)

# Remove time duplicates
tracks <- psyosphere::average_duplicates(tracks)

# Mark time interval gaps between coordinates
tracks <- psyosphere::t_time_difference(tracks)
tracks <- psyosphere::mark_time_gaps(tracks)

save.image("leadership3/rdata/06.RData")

# 07 Add speed -----------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/06.RData")

# Add speed
tracks <- psyosphere::t_speed(tracks)

# Mark impossible speed (above 40km/h) as gaps
tracks <- psyosphere::mark_speed_gaps(tracks,40)

save.image("leadership3/rdata/07.RData")

# 08 Save all plots but do not display them ------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/07.RData")

# All plots are created that where included and cleaned up. All gaps are marked
# as red lines. These gaps will be excluded from the further analysis.

psyosphere::plot_tracks(
  tracks, single = FALSE, save_dir = "leadership3/plots",
  cgaps = c("time_gap", "speed_gap")
)

save.image("leadership3/rdata/08.RData")

# 09 Add bearing ---------------------------------------------------------------

# This function will add the bearing between each point of a track.

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/08.RData")

tracks <- psyosphere::t_bearing(tracks)

save.image("leadership3/rdata/09.RData")

# 10 Add distance --------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/09.RData")

tracks <- psyosphere::t_distance(tracks)

save.image("leadership3/rdata/10.RData")

# 11 Add average distance to team mates ----------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/10.RData")

tracks <- psyosphere::distance_peers(tracks, cpeer = "team")

save.image("leadership3/rdata/11.RData")

# 12 Add average distance to formal followers in team --------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/11.RData")

follower_tracks <- tracks[ tracks[,c("formal_leader")] != 1  ,]
follower_tracks <- psyosphere::distance_peers(
  follower_tracks, cpeer = "team", cname = "formal_follower_mean_dis"
)

leader_tracks <- tracks[ tracks[,c("formal_leader")] == 1  ,]
leader_tracks[c("formal_follower_mean_dis")] <- leader_tracks[c("average_dis")]

tracks <- rbind(follower_tracks, leader_tracks)
tracks <- tracks[order(tracks$id, tracks$p_id),]

remove(follower_tracks, leader_tracks)

save.image("leadership3/rdata/12.RData")

# 13 Add average distance to perceived followers in team -----------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/12.RData")

follower_tracks <- tracks[ tracks[,c("perceived_leader")] != 1  ,]
follower_tracks <- psyosphere::distance_peers(
  follower_tracks, cpeer = "team", cname = "perceived_follower_mean_dis"
)

leader_tracks <- tracks[ tracks[,c("perceived_leader")] == 1  ,]
leader_tracks[c("perceived_follower_mean_dis")] <-
  leader_tracks[c("average_dis")]

tracks <- rbind(follower_tracks, leader_tracks)
tracks <- tracks[order(tracks$id, tracks$p_id),]

remove(follower_tracks, leader_tracks)

save.image("leadership3/rdata/13.RData")

# 14 Create summary data frame -------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/13.RData")

cgaps <- c("time_gap","speed_gap")

summary <- des_summary(tracks, cgaps = cgaps)

summary <- des_first(
  tracks, "formal_leader", cname = "formal_leader", des_df = summary
)

summary <- des_first(
  tracks, "perceived_leader", cname = "perceived_leader", des_df = summary
)

summary <- des_sd(
  tracks, ctarget = "speed", cweight = "time_difference", cgaps = cgaps,
  cname = "sd_kmh", des_df = summary
)

summary <- des_mean(
  tracks, ctarget = "average_dis", cweight = "time_difference",
  cgaps = cgaps, cname = "mean_team_distance", des_df = summary
)

summary <- des_mean(
  tracks, ctarget = "formal_follower_mean_dis", cweight = "time_difference",
  cgaps = cgaps, cname = "mean_formal_follower_dis", des_df = summary
)

summary <- des_mean(
  tracks, ctarget = "perceived_follower_mean_dis", cweight = "time_difference",
  cgaps = cgaps, cname = "mean_perceived_follower_dis", des_df = summary
)

summary <- des_first(tracks, "comment", cname = "comment", des_df = summary)

save.image("leadership3/rdata/14.RData")

# 15 Export to excel -----------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("leadership3/rdata/14.RData")

library(xlsx)
xlsx::write.xlsx(summary, "leadership3/leadership3.xlsx")
