#
#
#
#
#
#
#
#
#
#
# Read me first:
#
# Before you start you should make sure that the working directory is set to the
# directory of this file.
#
# You can find an explanation of this experiment on our website:
# https://analyse-gps.com/experiments/ut-smuggle-experiment/
#
#
#
#
#
#
#
#
#
#

library(psyosphere)

# 00 Check directories ---------------------------------------------------------

if (!file.exists("smuggler2.R")) {stop("Please set the working dir correctly")}

dir.create("smuggler2", showWarnings = FALSE)

dir.create("smuggler2/rdata", showWarnings = FALSE)
dir.create("smuggler2/plots", showWarnings = FALSE)
dir.create("smuggler2/gps_files", showWarnings = FALSE)

# 01 store GPX files in data frame ---------------------------------------------

# Download and unzip files
url <- "https://analyse-gps.com/downloads/smuggle2.zip"
download.file(url = url, destfile = "smuggler2/gps_files.zip")
unzip("smuggler2/gps_files.zip", exdir = "smuggler2/gps_files")
remove(url)

# Save GPS files with participant movement as dataframe
tracks <- psyosphere::dir_get_gpx("smuggler2/gps_files")

save.image("smuggler2/rdata/01.RData")

# 02 add information from id file to data frame --------------------------------

# The CSV stores some data about each participants that will be added to the
# data frame.

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/01.RData")

tracks <- psyosphere::dir_add_csv(tracks, "smuggler2/gps_files/ids.csv")

# Get first descriptives
begin_des <- des_summary(tracks)

save.image("smuggler2/rdata/02.RData")

# 03 clean-up data -------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/02.RData")

# Remove time duplicates
tracks <- psyosphere::average_duplicates(tracks)

# Mark time interval gaps between coordinates
tracks <- psyosphere::t_time_difference(tracks)
tracks <- psyosphere::mark_time_gaps(tracks)

save.image("smuggler2/rdata/03.RData")

# 04 add speed -----------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/03.RData")

# Add speed
tracks <- psyosphere::t_speed(tracks)

# Mark impossible speed as gaps
tracks <- psyosphere::mark_speed_gaps(tracks,40)

# Save the gap names for later use
cgaps <- c("time_gap","speed_gap")

save.image("smuggler2/rdata/04.RData")

# 05 save all plots but do not display them ------------------------------------

# The plots are generated to give you an idea how the data look like. You can
# check the plots in the plots folder in this directory.

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/04.RData")

psyosphere::plot_tracks(
  tracks, single = FALSE, save_dir = "smuggler2/plots", cgaps = cgaps
)

save.image("smuggler2/rdata/05.RData")

# 06 add bearing ---------------------------------------------------------------

# This function will add the bearing between each point of a track.

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/05.RData")

tracks <- psyosphere::t_bearing(tracks)

save.image("smuggler2/rdata/06.RData")

# 07 add distance --------------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/06.RData")

tracks <- psyosphere::t_distance(tracks)

save.image("smuggler2/rdata/07.RData")

# 08 set start and finish areas ------------------------------------------------

# The participants walked several rounds from start to finish. We are only
# interested in the data between start and finish and want to save them
# as seperate tracks / rounds. First we create the start and finish areas
# as closed polygons.

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/07.RData")

lon <- c(6.849975, 6.849627, 6.850001, 6.850350, 6.849975)
lat <- c(52.241745, 52.241100, 52.241004, 52.241649, 52.241745)
polygon_start <- data.frame(lon, lat)
remove(lon, lat)

lon <- c(6.851810, 6.851000, 6.851489, 6.852296, 6.851810)
lat <- c(52.241800, 52.240300, 52.240163, 52.241657, 52.241794)
polygon_finish <- data.frame(lon, lat)
remove(lon, lat)

save.image("smuggler2/rdata/08.RData")

# 09 map tracks and shapes -----------------------------------------------------

# We map the gps data and the start and finish polygons with Google Maps. It
# will take some time before the plot images appears because of the high amount
# of data.

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/08.RData")

# The gaps are omitted because plotting them costs a lot of extra time
plot_all <- psyosphere::plot_tracks(tracks, single = FALSE, t_id = "")
plot_all <- psyosphere::plot_polygon(polygon_start, plot = plot_all)
plot_all <- psyosphere::plot_polygon(polygon_finish, plot = plot_all)
plot_all

save.image("smuggler2/rdata/09.RData")

# 10 select tracks between start and finish ------------------------------------

# We select the different rounds of each participant and drop the other data.

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/09.RData")

tracks <- psyosphere::select_between_polygons(
  tracks, polygon_start, polygon_finish
)

save.image("smuggler2/rdata/10.RData")

# 11 map tracks without guards ------------------------------------------------

# We plot now the results without the border guards. You can see clearly that
# only the movement between start and finish remain.

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/10.RData")

tracks_without_guards <- tracks[!tracks$tracker %in% c(2,61,28),]

# The gaps are omitted because plotting them costs a lot of extra time
plot_rou <- psyosphere::plot_tracks(tracks_without_guards, t_id = "", zoom = 17)
plot_rou <- psyosphere::plot_polygon(polygon_start, plot = plot_rou)
plot_rou <- psyosphere::plot_polygon(polygon_finish, plot = plot_rou)
plot_rou

remove(tracks_without_guards)

save.image("smuggler2/rdata/11.RData")

# 12 plot tracks by participants -----------------------------------------------

# We want to check how each seperate round looks like. This will generate more
# than 200 plots. You can review the plots in the plots folder.

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/11.RData")

psyosphere::plot_tracks(
  tracks, single = FALSE, save_dir = "smuggler2/plots", cgaps = cgaps
)

save.image("smuggler2/rdata/12.RData")

# 13 mark if border guards are visible -----------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/12.RData")

polygon_guard_lon <- c(
  6.851234, 6.851129, 6.850950, 6.850821, 6.850699, 6.850582, 6.850477,
  6.850410, 6.850362, 6.850362, 6.850378, 6.850424, 6.850478, 6.850540,
  6.850705, 6.850898, 6.851100, 6.851255, 6.851399, 6.851942, 6.851234
)

polygon_guard_lat <- c(
  52.240456, 52.240448, 52.240478, 52.240531, 52.240601, 52.240666, 52.240772,
  52.240894, 52.241018, 52.241146, 52.241266, 52.241381, 52.241490, 52.241585,
  52.241656, 52.241698, 52.241717, 52.241706, 52.241662, 52.241620, 52.240456
)

polygon_guard <- data.frame(lon = polygon_guard_lon,lat = polygon_guard_lat)
remove(polygon_guard_lon, polygon_guard_lat)

psyosphere::plot_polygon(polygon_guard, plot = plot_rou)

tracks <- psyosphere::mark_inside_polygon(
  tracks, polygon_guard, cname = "guard_vis"
)

save.image("smuggler2/rdata/13.RData")

# 14 add distance to finish ----------------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/13.RData")

finish <- data.frame(lon = c(6.851810,6.851000), lat = c(52.241800,52.240300))

psyosphere::plot_line(finish, plot = plot_rou)

tracks <- psyosphere::distance_line(tracks,finish, TRUE)

save.image("smuggler2/rdata/14.RData")

# 15 add distance to shortest route from begin ---------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/14.RData")

tracks <- psyosphere::distance_to_direct_line(
  tracks,finish, cname = "deviation"
)

remove(finish)

save.image("smuggler2/rdata/15.RData")

# 16 add average distance to team mates ----------------------------------------

# Be aware this functions can take a lot of time because of the many positions.
# With the following code you can test the calculation first:
#
# tracks_test <- psyosphere::select_test_sample(tracks)
# tracks_test <- psyosphere::distance_peers(tracks_test, peer_col = "team")

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/15.RData")

tracks <- psyosphere::distance_peers(tracks, cpeer = "team")

save.image("smuggler2/rdata/16.RData")

# 17 add distance to border guards ---------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/16.RData")

guard_tracks <- tracks[ tracks$tracker %in% c(2,61,28) ,]
tracks <- tracks[ !tracks$tracker %in% c(2,61,28) ,]

tracks <- psyosphere::distance_psyo(tracks, guard_tracks)

tracks <- plyr::rename(
  tracks, c(
    "dis_to_02.gpx_1_in_m" = "dis_guard1",
    "dis_to_28.gpx_1_in_m" = "dis_guard2",
    "dis_to_61.gpx_1_in_m" = "dis_guard3"
  )
)

save.image("smuggler2/rdata/17.RData")

# 18 create summary data frame -------------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/17.RData")

cgaps <- c("time_gap","speed_gap")
cweight <- "time_difference"

# Descriptives of the whole tracks
summary <- psyosphere::des_summary(tracks, cgaps = cgaps)
summary <- psyosphere::des_first(tracks, "track", cname = "round", des_df = summary)

summary <- psyosphere::des_sd(
  tracks, ctarget = "speed", cweight = cweight, cgaps = cgaps,
  cname = "sd_kmh", des_df = summary
)

summary <- psyosphere::des_mean(
  tracks, ctarget = "average_dis", cweight = cweight,
  cgaps = cgaps, cname = "mean_team_distance", des_df = summary
)

summary <- psyosphere::des_mean(
  tracks, ctarget = "deviation", cweight = cweight,
  cgaps = cgaps, cname = "mean_deviation_route", des_df = summary
)

summary <- psyosphere::des_sd(
  tracks, ctarget = "deviation", cweight = cweight, cgaps = cgaps,
  cname = "sd_deviation_route", des_df = summary
)

# Before hill descriptives

bh_tracks <- tracks[tracks$guard_vis %in% c(0),]

summary <- psyosphere::des_mean(
  bh_tracks, ctarget = "speed", cweight = cweight,
  cgaps = cgaps, cname = "bh_mean_kmh", des_df = summary
)

summary <- psyosphere::des_sd(
  bh_tracks, ctarget = "speed", cweight = cweight, cgaps = cgaps,
  cname = "bh_sd_kmh", des_df = summary
)

summary <- psyosphere::des_mean(
  bh_tracks, ctarget = "average_dis", cweight = cweight,
  cgaps = cgaps, cname = "bh_mean_team_distance", des_df = summary
)

summary <- psyosphere::des_mean(
  bh_tracks, ctarget = "deviation", cweight = cweight,
  cgaps = cgaps, cname = "bh_mean_deviation_route", des_df = summary
)

summary <- psyosphere::des_sd(
  bh_tracks, ctarget = "deviation", cweight = cweight, cgaps = cgaps,
  cname = "bh_sd_deviation_route", des_df = summary
)

# After hill descriptives

ah_tracks <- tracks[tracks$guard_vis %in% c(1),]

summary <- psyosphere::des_mean(
  ah_tracks, ctarget = "speed", cweight = cweight,
  cgaps = cgaps, cname = "ah_mean_kmh", des_df = summary
)

summary <- psyosphere::des_sd(
  ah_tracks, ctarget = "speed", cweight = cweight, cgaps = cgaps,
  cname = "ah_sd_kmh", des_df = summary
)

summary <- psyosphere::des_mean(
  ah_tracks, ctarget = "average_dis", cweight = cweight,
  cgaps = cgaps, cname = "ah_mean_team_distance", des_df = summary
)

summary <- psyosphere::des_mean(
  ah_tracks, ctarget = "deviation", cweight = cweight,
  cgaps = cgaps, cname = "ah_mean_deviation_route", des_df = summary
)

summary <- psyosphere::des_sd(
  ah_tracks, ctarget = "deviation", cweight = cweight, cgaps = cgaps,
  cname = "ah_sd_deviation_route", des_df = summary
)

save.image("smuggler2/rdata/18.RData")

# 19 export to excel -----------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/18.RData")

library(xlsx)
xlsx::write.xlsx(summary, "smuggler2/smuggler2.xlsx")

save.image("smuggler2/rdata/19.RData")

# 20 set colors per track ------------------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/19.RData")

# create dir

dir.create("smuggler2/tracks", showWarnings = FALSE)

# download and unzip file with package data

url <- "https://analyse-gps.com/downloads/packages.zip"
download.file(url = url, destfile = "smuggler2/packages.zip")
unzip("smuggler2/packages.zip", exdir = "smuggler2")
remove(url)

load("smuggler2/packages.RData")

# Smuggler tracks

ah_tracks[,"hist_track_id"] <- paste0("S2_",ah_tracks[,"id"])
ah_tracks <- merge(ah_tracks, package, by = "hist_track_id", all.x = TRUE)
ah_tracks[,"track_color"] <- ifelse(ah_tracks[,"cocaine"], "#00000099", "#ffffff99")
ah_tracks[,"track_name"] <- ah_tracks[,"team"]

ah_tracks[,"file_name"] <- paste0(
  "smuggler2/tracks/", ah_tracks[,"hist_track_id"], ".kml"
)

# Guard tracks

guard_tracks[,"track_color"] <- "#00ff0000"

guard_tracks[,"track_name"] <- ifelse(
  guard_tracks[,"id"] == "02.gpx_1", "G1",
    ifelse(
      guard_tracks[,"id"] == "28.gpx_1", "G2",
        ifelse(
          guard_tracks[,"id"] == "61.gpx_1", "G3",
            NA
        )
    )
)

guard_tracks[,"file_name"] <- paste0(
  "smuggler2/tracks/", guard_tracks[,"track_name"], ".kml"
)

save.image("smuggler2/rdata/20.RData")

# 21 export tracks with colors -------------------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/20.RData")

psyosphere::export_kml(ah_tracks)
psyosphere::export_kml(guard_tracks)

save.image("smuggler2/rdata/21.RData")

# 22 illustrate tracks for publication -----------------------------------------

rm(list = ls(all.names = TRUE))
load("smuggler2/rdata/21.RData")

# set colors

tracks[,"hist_track_id"] <- paste0("S2_",tracks[,"id"])
tracks <- merge(tracks, package, by = "hist_track_id", all.x = TRUE)
tracks[,"track_color"] <- ifelse(tracks[,"cocaine"], "#00000099", "#ffffff99")

tracks[,"track_color"] <- tracks[,"track_color"]

# select tracks

tracks[,"team"] <- as.character(tracks[,"team"])

tracks_sel <- tracks[
  tracks[,"team"] == 15 & tracks[,"track"] == 1,
]

plot_info <- psyosphere::plot_map( rbind(polygon_start, polygon_finish), zoom = 18)
plot_info <- psyosphere::plot_polygon(polygon_start, plot = plot_info)
plot_info <- psyosphere::plot_polygon(polygon_finish, plot = plot_info)
plot_info <- psyosphere::plot_polygon(polygon_guard, plot = plot_info)
psyosphere::plot_tracks(tracks_sel, plot = plot_info, dots = FALSE)

save.image("smuggler2/rdata/21.RData")
